Training a neural network
===========================

itwinai aims at simplifying the way you train deep learning models, helping you to scale training to HPC resources,
while integrating popular logging frameworks, such as MLFlow, Weights&Biases, and Tensorboard.

itwinai TorchTrainer
-------------------------

Below, you can find some tutorials that will help you getting familiar with the itwinai **TorchTrainer**:

.. raw:: html
   
    <iframe width="560" height="315" src="https://www.youtube.com/embed/m95W9T2FYLI?si=ETAzykd4DQDEOud7" title="TorchTrainer [Part 1]" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

|

.. raw:: html
   
    <iframe width="560" height="315" src="https://www.youtube.com/embed/u85RBTwS2nc?si=etL9Bxma6SMsb5yT" title="TorchTrainer [Part 2]" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>

|

.. include:: explain_ddp.rst
